Learn R Programming

biomartr (version 0.5.1)

getRNA: RNA Sequence Retrieval

Description

Main retrieval function for RNA sequences of an organism of interest. By specifying the scientific name of an organism of interest the corresponding fasta-file storing the RNA information for the organism of interest can be downloaded and stored locally. RNA files can be retrieved from several databases.

Usage

getRNA(db = "refseq", organism, path = file.path("_ncbi_downloads", "RNA"))

Arguments

db
a character string specifying the database from which the genome shall be retrieved: db = "refseq", db = "genbank", db = "ensembl" or db = "ensemblgenomes".
organism
a character string specifying the scientific name of the organism of interest,organism = "Homo sapiens".
path
a character string specifying the location (a folder) in which the corresponding CDS file shall be stored. Default is path = file.path("_ncbi_downloads","RNA").

Value

File path to downloaded RNA file.

See Also

getGenome, getProteome, getGTF, getGFF, meta.retrieval, read_cds, getCDS

Examples

Run this code
## Not run: ------------------------------------
# # download the RNA of Arabidopsis thaliana from refseq
# # and store the corresponding RNA file in '_ncbi_downloads/RNA'
# file_path <- getRNA( db       = "refseq", 
#              organism = "Arabidopsis thaliana", 
#              path     = file.path("_ncbi_downloads","RNA"))
# 
# Ath_RNA <- read_rna(file_path, format = "fasta")
## ---------------------------------------------

Run the code above in your browser using DataLab