read_cds(file, format = "fasta", obj.type = "Biostrings",
delete_corrupt = FALSE, ...)format = "fasta" (default) or format = "gbk".obj.type = "Biostrings" (default) or as
obj.type = "data.table".delete_corrupt = FALSE.read.fasta.read.cds function takes a string specifying the path
to the cds file of interest as first argument.It is possible to read in different proteome file standards such as fasta or genebank.
CDS stored in fasta files can be downloaded from http://www.ensembl.org/info/data/ftp/index.html.
getCDS, read_genome,
read_proteome, read_gff, read_rna