read_rm: Import Repeat Masker output file
Description
This function reads an organism specific
Repeat Masker output file.Arguments
file
a character string specifying the path to the file
storing the Repeat Masker output (e.g. retrieved with getRepeatMasker). Details
This function takes a string specifying the path to the
Repeat Masker output file of interest as first argument.