Learn R Programming

biomartr (version 0.5.1)

download.database.all: Download all elements of an NCBI databse

Description

The download.database functions allows users to retrieve individual packages of a NCBI database. This function is designed to retrieve the entire database selected by the users (hence all packages corresponding to this database).

Usage

download.database.all(db, path = "database")

Arguments

db
a character string specifying the database that shall be downloaded (selected from listDatabases).
path
a character string specifying the location (a folder) in which the corresponding database shall be stored. In case this folder does not exist yet, it will be created.

Value

A character vector storing the file paths of the downloaded databases.

See Also

download.database, listNCBIDatabases

Examples

Run this code
# search for available NCBI databases
  listNCBIDatabases(db = "all")
## Not run: ------------------------------------
#   
# # choose database NCBI nr and download compelete database
#   download.database.all(name = "nr", path = "nr")
## ---------------------------------------------

Run the code above in your browser using DataLab