## Not run: ------------------------------------
# # download the genome assembly stats file of Saccharomyces cerevisiae
# # from NCBI RefSeq
# # and store the corresponding genome file in
# # '_ncbi_downloads/genomeassembly_stats'
# file_path <- getAssemblyStats( db = "refseq",
# organism = "Saccharomyces cerevisiae",
# path = file.path("_ncbi_downloads","genomeassembly_stats"))
# # import the raw file as it is downloaded
# Scerevisiae.stats <- read_assemblystats(file_path, type = "raw")
#
# # download the genome assembly stats file of Saccharomyces cerevisiae
# # from NCBI RefSeq
# # and import overall statistics of the genome assembly
# Scerevisiae.stats.import <- getAssemblyStats( db = "refseq",
# organism = "Saccharomyces cerevisiae",
# type = "import",
# path = file.path("_ncbi_downloads","genomeassembly_stats"))
## ---------------------------------------------
Run the code above in your browser using DataLab