## Not run: ------------------------------------
#
# # download the Repeat Masker output file of Arabidopsis thaliana from refseq
# # and store the corresponding genome file in '_ncbi_downloads/genomes'
# file_path <- getRepeatMasker( db = "refseq",
# organism = "Arabidopsis thaliana",
# path = file.path("_ncbi_downloads","repeatmasker"))
#
# Ath_repeatmasker <- read_rm(file_path)
#
#
# # download the Repeat Masker output file of Arabidopsis thaliana from genbank
# # and store the corresponding genome file in '_ncbi_downloads/genomes'
# file_path <- getRepeatMasker( db = "genbank",
# organism = "Arabidopsis thaliana",
# path = file.path("_ncbi_downloads","repeatmasker"))
#
# Ath_repeatmasker <- read_rm(file_path)
## ---------------------------------------------
Run the code above in your browser using DataLab