Arguments
db
a character string specifying the database for which genome
availability shall be checked, e.g. db = "refseq",
db = "genbank", db = "ensembl", db = "ensemblgenomes".
type
a character string specifying a potential filter of available
genomes. Options are type = "all", type = "kingdom",
type = "group", type = "subgroup".
subset
a character string or character vector specifying a subset of
type. E.g. if users are interested in retrieving all
Eukaryota species, they can specify: type = "kingdom" and
subset = "Eukaryota".
details
a boolean value specifying whether only the scientific names
of stored genomes shall be returned (details = FALSE) or all information such
as organism_name,kingdoms, group, subgroup,
file_size_MB, etc.